pub struct PreparedOrderPath { /* private fields */ }Expand description
Prepared low-latency order path for a single market/token configuration.
Implementations
Sourceimpl PreparedOrderPath
impl PreparedOrderPath
Sourcepub fn create_limit_order(
&self,
side: Side,
price: Decimal,
size: Decimal,
expiration: Option<u64>,
) -> Result<SignedOrderRequest>
pub fn create_limit_order( &self, side: Side, price: Decimal, size: Decimal, expiration: Option<u64>, ) -> Result<SignedOrderRequest>
Create and sign a limit order using the cached market/token context.
Sourcepub fn create_market_order(
&self,
side: Side,
amount: Decimal,
price: Decimal,
order_type: OrderType,
) -> Result<SignedOrderRequest>
pub fn create_market_order( &self, side: Side, amount: Decimal, price: Decimal, order_type: OrderType, ) -> Result<SignedOrderRequest>
Create and sign a market order using the cached market/token context.